// (C) 2007-2025 GoodData Corporation
import React from "react";
import unescape from "lodash/unescape.js";
import { withTheme } from "@gooddata/sdk-ui-theme-provider";
import { useIdPrefixed } from "@gooddata/sdk-ui-kit";
const DEFAULT_DISABLED_COLOR = "#CCCCCC";
const LegendItem = ({ item, width, enableBorderRadius = false, onItemClick, theme, }) => {
    const disabledColor = theme?.palette?.complementary?.c5 ?? DEFAULT_DISABLED_COLOR;
    const iconStyle = {
        borderRadius: enableBorderRadius ? "50%" : "0",
        backgroundColor: item.isVisible ? item.color : disabledColor,
    };
    // normal state styled by css
    const nameStyle = item.isVisible
        ? {}
        : {
            color: disabledColor,
        };
    const style = width ? { width: `${width}px` } : {};
    const handleItemClick = () => {
        return onItemClick(item);
    };
    const legendItemId = useIdPrefixed("legend-item");
    return (React.createElement("button", { "data-testid": "legend-item", style: style, className: "series-item", onClick: handleItemClick, "aria-labelledby": legendItemId, title: unescape(item.name) },
        React.createElement("div", { className: "series-icon", style: iconStyle }),
        React.createElement("div", { id: legendItemId, className: "series-name", style: nameStyle }, item.name)));
};
export default withTheme(LegendItem);
//# sourceMappingURL=LegendItem.js.map