// (C) 2007-2025 GoodData Corporation
import React from "react";
import cx from "classnames";
import { ZoomAwareOverlay, useMediaQuery, useIsZoomed, ZOOM_THRESHOLD } from "@gooddata/sdk-ui-kit";
import { legendDialogAlignPoints, legendMobileDialogAlignPoints } from "./alignPoints.js";
const LegendDialogWrapper = ({ children }) => {
    const isMobile = useMediaQuery("<sm");
    return children(isMobile);
};
const LegendDialogContent = (props) => {
    const { title, onCloseDialog, children } = props;
    const isZoomed = useIsZoomed(ZOOM_THRESHOLD);
    const onClose = (e) => {
        e.preventDefault();
        onCloseDialog();
    };
    const className = cx("legend-popup-dialog", "legend-popup-dialog-content", {
        zoomed: isZoomed,
    });
    return (React.createElement("div", { className: className },
        React.createElement("div", { className: "legend-header" },
            React.createElement("div", { className: "legend-header-title" }, title),
            React.createElement("div", { className: "s-legend-close legend-close gd-icon-cross gd-button-link gd-button-icon-only", onClick: onClose })),
        React.createElement("div", { className: "legend-content" }, children)));
};
export const LegendDialog = (props) => {
    const { name, children, isOpen, alignTo, onCloseDialog } = props;
    if (!isOpen) {
        return null;
    }
    return (React.createElement(LegendDialogWrapper, null, (isMobile) => {
        return (React.createElement(ZoomAwareOverlay, { alignTo: alignTo, alignPoints: isMobile ? legendMobileDialogAlignPoints : legendDialogAlignPoints, closeOnOutsideClick: !isMobile, onClose: onCloseDialog, className: "kpi-alert-dialog-overlay", ensureVisibility: true },
            React.createElement(LegendDialogContent, { title: name, onCloseDialog: onCloseDialog }, children)));
    }));
};
//# sourceMappingURL=LegendDialog.js.map